@@ -86,12 +86,7 @@ class RepliteDirective(SphinxDirective):
         return [RepliteIframe(width=width, height=height, replite_options=self.options)]
 
 
-class RetroliteIframe(Element):
-    """Appended to the doctree by the RetroliteDirective directive
-
-    Renders an iframe that shows a Notebook with RetroLite.
-    """
-
+class _LiteIframe(Element):
     def __init__(
         self,
         rawsource="",
@@ -106,36 +101,89 @@ class RetroliteIframe(Element):
     def html(self):
         notebook = self["notebook"]
 
+        src = (
+            f"{JUPYTERLITE_DIR}/{self.lite_app}/{self.notebooks_path}?path={notebook}"
+            if notebook is not None
+            else f"{JUPYTERLITE_DIR}/{self.lite_app}"
+        )
+
         return (
-            f'<iframe src="{JUPYTERLITE_DIR}/retro/notebooks/?path={notebook}"'
+            f'<iframe src="{src}"'
             f'width="{self["width"]}" height="{self["height"]}" style="{IFRAME_STYLE}"></iframe>'
         )
 
 
-class RetroliteDirective(SphinxDirective):
+class JupyterLiteIframe(_LiteIframe):
+    """Appended to the doctree by the JupyterliteDirective directive
+
+    Renders an iframe that shows a Notebook with JupyterLite.
+    """
+
+    lite_app = "lab"
+    notebooks_path = ""
+
+
+class RetroLiteIframe(_LiteIframe):
+    """Appended to the doctree by the RetroliteDirective directive
+
+    Renders an iframe that shows a Notebook with RetroLite.
+    """
+
+    lite_app = "retro"
+    notebooks_path = "notebooks/"
+
+
+class _LiteDirective(SphinxDirective):
+
+    has_content = False
+    optional_arguments = 1
+    option_spec = {
+        "width": directives.unchanged,
+        "height": directives.unchanged,
+    }
+
+    def run(self):
+        width = self.options.get("width", "100%")
+        height = self.options.get("height", "1000px")
+
+        if self.arguments:
+            notebook = self.arguments[0]
+
+            # If we didn't get an absolute path,
+            # try to find the Notebook relatively to the source
+            if not os.path.isabs(notebook):
+                source_location = os.path.dirname(self.get_source_info()[0])
+                notebook = os.path.join(source_location, notebook)
+
+            notebook_name = os.path.basename(notebook)
+
+            notebooks_dir = Path(self.env.app.srcdir) / CONTENT_DIR / notebook_name
+
+            # Copy the Notebook for RetroLite to find
+            os.makedirs(os.path.dirname(notebooks_dir), exist_ok=True)
+            shutil.copyfile(notebook, str(notebooks_dir))
+        else:
+            notebook_name = None
+
+        return [self.iframe_cls(notebook=notebook_name, width=width, height=height)]
+
+
+class JupyterLiteDirective(_LiteDirective):
+    """The ``.. jupyterlite::`` directive.
+
+    Renders a Notebook with JupyterLite in the docs.
+    """
+
+    iframe_cls = JupyterLiteIframe
+
+
+class RetroLiteDirective(_LiteDirective):
     """The ``.. retrolite::`` directive.
 
     Renders a Notebook with RetroLite in the docs.
     """
 
-    has_content = False
-    required_arguments = 1
-    option_spec = {}
-
-    def run(self):
-        notebook = self.arguments[0]
-        notebook_name = os.path.basename(notebook)
-
-        width = self.options.get("width", "100%")
-        height = self.options.get("height", "1000px")
-
-        notebooks_dir = Path(self.env.app.srcdir) / CONTENT_DIR / notebook_name
-
-        # Copy the Notebook for RetroLite to find
-        os.makedirs(os.path.dirname(notebooks_dir), exist_ok=True)
-        shutil.copyfile(notebook, str(notebooks_dir))
-
-        return [RetroliteIframe(notebook=notebook_name, width=width, height=height)]
+    iframe_cls = RetroLiteIframe
 
 
 class RetroLiteParser(rst.Parser):
@@ -194,7 +242,6 @@ def jupyterlite_build(app: Sphinx, error):
 
 
 def setup(app):
-    # Build the JupyterLite output
     app.connect("config-inited", inited)
     # We need to build JupyterLite at the end, when all the content was created
     app.connect("build-finished", jupyterlite_build)
@@ -202,17 +249,27 @@ def setup(app):
     # Config options
     app.add_config_value("jupyterlite_config", None, rebuild="html")
 
-    # Initialize RetroLite directive and parser
+    # Initialize RetroLite and JupyterLite directives
     app.add_node(
-        RetroliteIframe,
+        RetroLiteIframe,
         html=(visit_element_html, None),
         latex=(skip, None),
         textinfo=(skip, None),
         text=(skip, None),
         man=(skip, None),
     )
-    app.add_directive("retrolite", RetroliteDirective)
+    app.add_directive("retrolite", RetroLiteDirective)
+    app.add_node(
+        JupyterLiteIframe,
+        html=(visit_element_html, None),
+        latex=(skip, None),
+        textinfo=(skip, None),
+        text=(skip, None),
+        man=(skip, None),
+    )
+    app.add_directive("jupyterlite", JupyterLiteDirective)
 
+    # Initialize RetroLite parser
     app.add_source_parser(RetroLiteParser)
     app.add_source_suffix(".ipynb", "jupyterlite_notebook")
 
